@@ -14,6 +14,7 @@
 # limitations under the License.
 
 from abc import abstractmethod
+from collections import OrderedDict
 from collections.abc import Callable, Iterator, MutableMapping
 from functools import partial
 from inspect import Signature, isfunction
@@ -24,6 +25,7 @@ from ._errors import Error, ErrorEnum
 __all__: Final[list[str]] = ["Dispatcher"]
 
 _AnyCallable: TypeAlias = Callable[..., Any]
+_D = TypeVar("_D", bound="BaseDispatcher")
 _F = TypeVar("_F", bound=_AnyCallable)
 
 
@@ -31,16 +33,17 @@ class BaseDispatcher(MutableMapping[str, _AnyCallable]):
     __slots__: list[str] = ["_registry"]
 
     def __init__(self) -> None:
-        self._registry: Final[dict[str, _AnyCallable]] = dict()
+        self._registry: Final[OrderedDict[str, _AnyCallable]] = OrderedDict()
 
     def __hash__(self) -> int:
-        return hash(frozenset(self.items()))
+        return hash(tuple(objects := self.items())) ^ len(objects)
 
     def __getitem__(self, key: str, /) -> _AnyCallable:
         return self._registry[key]
 
     def __setitem__(self, key: str, value: _AnyCallable, /) -> None:
         self._registry[key] = value
+        self._registry.move_to_end(key)
 
     def __delitem__(self, key: str, /) -> None:
         del self._registry[key]
@@ -54,6 +57,31 @@ class BaseDispatcher(MutableMapping[str, _AnyCallable]):
     def __contains__(self, obj: Any, /) -> bool:
         return obj in self._registry
 
+    def __or__(self: type[_D], obj: MutableMapping[str, _AnyCallable], /) -> _D:
+        if not isinstance(obj, MutableMapping):
+            return NotImplemented
+
+        dispatcher: Final[_D] = self.__class__()
+        dispatcher.update(self)
+        dispatcher.update(obj)
+        return dispatcher
+
+    def __ror__(self: type[_D], obj: MutableMapping[str, _AnyCallable], /) -> _D:
+        if not isinstance(obj, MutableMapping):
+            return NotImplemented
+
+        dispatcher: Final[_D] = self.__class__()
+        dispatcher.update(obj)
+        dispatcher.update(self)
+        return dispatcher
+
+    def __ior__(self: type[_D], obj: MutableMapping[str, _AnyCallable], /) -> _D:
+        if not isinstance(obj, MutableMapping):
+            return NotImplemented
+
+        self.update(obj)
+        return self
+
     @abstractmethod
     def register(self, user_function: _F | None = None, *, function_name: str | None = None) -> _F | Callable[[_F], _F]:
         raise NotImplementedError
@@ -70,7 +98,7 @@ class Dispatcher(BaseDispatcher):
     __slots__: tuple[str, ...] = ()
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}()>"
+        return f"<{__package__}.{self.__class__.__qualname__}()>"
 
     def register(self, user_function: _F | None = None, *, function_name: str | None = None) -> _F | Callable[[_F], _F]:
         """
@@ -140,11 +168,8 @@ class Dispatcher(BaseDispatcher):
         except TypeError as exc:
             raise Error(code=ErrorEnum.INVALID_PARAMETERS, message=f"Invalid parameters: {exc!s}") from exc
 
-        # Save the callback for future use:
-        callback: Final[partial] = partial(user_function, *args, **kwargs)
-
         try:
-            return callback()
+            return user_function(*args, **kwargs)
         except Error:
             raise
         except Exception as exc:
