@@ -79,7 +79,7 @@ class Error(BaseError):
         return f"{self._message!s}\u0020\u0028{self._code:d}\u0029"
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}(" \
+        return f"<{__package__}.{self.__class__.__qualname__}(" \
             f"code={self._code!r}, " \
             f"message={self._message!r}, " \
             f"data={self._data!r})>"
