@@ -19,7 +19,7 @@ from numbers import Number
 from typing import Any, Final, TypeAlias, TypeVar
 
 from ._errors import Error, ErrorEnum
-from ._utilities import Undefined, UndefinedType, boolean_sorter, make_hashable
+from ._utilities import Undefined, UndefinedType, make_hashable, partition
 
 __all__: Final[list[str]] = ["BatchRequest", "Request"]
 
@@ -104,7 +104,7 @@ class Request(BaseRequest):
         self._id: Final[str | Number | UndefinedType] = self._is_request_id_valid(request_id=request_id)
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}(" \
+        return f"<{__package__}.{self.__class__.__qualname__}(" \
             f"method={self._method!r}, " \
             f"params={self._params!r}, " \
             f"request_id={self._id!r})>"
@@ -220,7 +220,7 @@ class BatchRequest(BaseBatchRequest[Request | Error]):
         self._requests: Final[tuple[Request | Error, ...]] = tuple(requests)
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}({self._requests!r})>"
+        return f"<{__package__}.{self.__class__.__qualname__}(\u2026)>"
 
     def __hash__(self) -> int:
         return hash(frozenset(self._requests)) ^ len(self._requests)
@@ -231,7 +231,7 @@ class BatchRequest(BaseBatchRequest[Request | Error]):
             and frozenset(self._requests) == frozenset(obj._requests)
 
     def __iter__(self) -> Iterator[Request | Error]:
-        return boolean_sorter(self._requests, lambda obj: isinstance(obj, Request) and obj.is_notification)
+        return partition(lambda obj: isinstance(obj, Request) and obj.is_notification, self._requests)
 
     def __len__(self) -> int:
         return len(self._requests)
