@@ -20,7 +20,7 @@ from types import NoneType
 from typing import Any, Final, TypeVar, overload
 
 from ._errors import Error
-from ._utilities import Undefined, UndefinedType, boolean_sorter, make_hashable
+from ._utilities import Undefined, UndefinedType, make_hashable, partition
 
 __all__: Final[list[str]] = ["BatchResponse", "Response"]
 
@@ -107,7 +107,7 @@ class Response(BaseResponse):
         self._id: Final[str | Number | UndefinedType | None] = self._is_response_id_valid(response_id=response_id)
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}(" \
+        return f"<{__package__}.{self.__class__.__qualname__}(" \
             f"body={self._body!r}, " \
             f"error={self._error!r}, " \
             f"response_id={self._id!r})>"
@@ -215,7 +215,7 @@ class BatchResponse(BaseBatchResponse[Response]):
         self._responses: Final[frozenset[Response]] = frozenset(responses)
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}(\u2026)>"
+        return f"<{__package__}.{self.__class__.__qualname__}(\u2026)>"
 
     def __hash__(self) -> int:
         return hash(self._responses) ^ len(self._responses)
@@ -226,7 +226,7 @@ class BatchResponse(BaseBatchResponse[Response]):
             and self._responses == obj._responses
 
     def __iter__(self) -> Iterator[Response]:
-        return boolean_sorter(self._responses, lambda response: response.is_successful)
+        return partition(lambda response: response.is_successful, self._responses)
 
     def __len__(self) -> int:
         return len(self._responses)
