@@ -19,9 +19,9 @@ from time import gmtime
 from typing import Any, Final, Literal, TypeVar
 
 __all__: Final[list[str]] = [
-    "boolean_sorter",
     "http_rfc2822_datetime",
     "make_hashable",
+    "partition",
     "Undefined",
     "UndefinedType"
 ]
@@ -29,12 +29,6 @@ __all__: Final[list[str]] = [
 _T = TypeVar("_T")
 
 
-def boolean_sorter(iterable: Iterable[_T], predicate: Callable[[_T], bool] | None = None, /) -> Iterator[_T]:
-    left, right = tee(iterable)
-    yield from filter(predicate, left)
-    yield from filterfalse(predicate, right)
-
-
 def http_rfc2822_datetime(timestamp: float | None = None) -> str:
     tm_year, tm_mon, tm_mday, tm_hour, tm_min, tm_sec, tm_wday, _, _ = gmtime(timestamp)
     return f"{['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'][tm_wday]}, {tm_mday:02d} " \
@@ -59,6 +53,13 @@ def make_hashable(obj: Any, /) -> Hashable:
     return obj
 
 
+def partition(predicate: Callable[[_T], bool] | None, iterable: Iterable[_T], /) -> Iterator[_T]:
+    # Use a predicate to partition entries into true entries and false entries.
+    left, right = tee(iterable)
+    yield from filter(predicate, left)
+    yield from filterfalse(predicate, right)
+
+
 class UndefinedType:
     __slots__: tuple[str, ...] = ()
 
