@@ -15,40 +15,44 @@
 
 from abc import abstractmethod
 from binascii import b2a_base64 as b64encode
+from collections import OrderedDict
 from collections.abc import Callable, Iterator, MutableMapping, MutableSequence
-from functools import partial
+from functools import partial, singledispatchmethod
 from hashlib import md5
 from http import HTTPStatus
 from io import DEFAULT_BUFFER_SIZE, BytesIO
+from sys import exc_info
 from threading import Thread
 from traceback import print_exception
-from typing import Any, ClassVar, Final, TypeAlias
+from typing import Any, ClassVar, Final, TypeAlias, TypeVar
 
 from ._dispatcher import Dispatcher
 from ._errors import Error
 from ._request import BatchRequest, Request
 from ._response import BatchResponse, Response
 from ._serializer import JSONSerializer
-from ._typing import ExcInfo, Headers, InputStream, StartResponse, WSGIEnvironment
+from ._typing import Headers, InputStream, OptExcInfo, StartResponse, WSGIEnvironment
 from ._utilities import http_rfc2822_datetime
 
 __all__: Final[list[str]] = ["WSGIHandler"]
 
 _AnyRequest: TypeAlias = Request | Error | BatchRequest
 _AnyResponse: TypeAlias = Response | BatchResponse | None
+_H = TypeVar("_H", bound="BaseWSGIHandler")
 
 
 class BaseWSGIHandler(MutableMapping[str, Any]):
     __slots__: list[str] = ["_options"]
 
-    def __init__(self, /, **kwargs: Any) -> None:
-        self._options: Final[dict[str, Any]] = kwargs.copy()
+    def __init__(self) -> None:
+        self._options: Final[OrderedDict[str, Any]] = OrderedDict()
 
     def __getitem__(self, key: str, /) -> Any:
         return self._options[key]
 
     def __setitem__(self, key: str, value: Any, /) -> None:
         self._options[key] = value
+        self._options.move_to_end(key)
 
     def __delitem__(self, key: str, /) -> None:
         del self._options[key]
@@ -62,6 +66,31 @@ class BaseWSGIHandler(MutableMapping[str, Any]):
     def __contains__(self, obj: Any, /) -> bool:
         return obj in self._options
 
+    def __or__(self: type[_H], obj: MutableMapping[str, Any], /) -> _H:
+        if not isinstance(obj, MutableMapping):
+            return NotImplemented
+
+        handler: Final[_H] = self.__class__()
+        handler.update(self)
+        handler.update(obj)
+        return handler
+
+    def __ror__(self: type[_H], obj: MutableMapping[str, Any], /) -> _H:
+        if not isinstance(obj, MutableMapping):
+            return NotImplemented
+
+        handler: Final[_H] = self.__class__()
+        handler.update(obj)
+        handler.update(self)
+        return handler
+
+    def __ior__(self: type[_H], obj: MutableMapping[str, Any], /) -> _H:
+        if not isinstance(obj, MutableMapping):
+            return NotImplemented
+
+        self.update(obj)
+        return self
+
     def __call__(self, environ: WSGIEnvironment, start_response: StartResponse, /) -> Iterator[bytes]:
         # Prevents the "start_response" argument duplicate invocation:
         wsgi_response: partial[Iterator[bytes]] = partial(self._get_response, start_response)
@@ -88,8 +117,7 @@ class BaseWSGIHandler(MutableMapping[str, Any]):
             # Houston, we have a problem O_o
             # In unexpected situations it raises the exception to WSGI server.
             print_exception(exc, file=environ["wsgi.errors"])
-            exc_info: Final[ExcInfo] = type(exc), exc, getattr(exc, "__traceback__")
-            return wsgi_response(status=HTTPStatus.INTERNAL_SERVER_ERROR, exc_info=exc_info)
+            return wsgi_response(status=HTTPStatus.INTERNAL_SERVER_ERROR, exc_info=exc_info())
 
     @property
     def _allowed_methods(self) -> Iterator[str]:
@@ -130,7 +158,7 @@ class BaseWSGIHandler(MutableMapping[str, Any]):
         status: HTTPStatus = HTTPStatus.OK,
         response_body: bytes | None = None,
         media_type: str = "application/json",
-        exc_info: ExcInfo | None = None
+        exc_info: OptExcInfo | None = None
     ) -> Iterator[bytes]:
         content_length: int = len(response_body := b"" if response_body is None else response_body)
         headers: Headers = [
@@ -147,22 +175,20 @@ class BaseWSGIHandler(MutableMapping[str, Any]):
 
         if status == HTTPStatus.METHOD_NOT_ALLOWED:
             # Fill the allowed request methods if the specified method is invalid:
-            headers.append(("Allow", "\x2C\x20".join(self._allowed_methods)))
+            headers.append(("Allow", "\u002c\u0020".join(self._allowed_methods)))
 
         # Sorting the headers before sending them to the server:
         headers.sort()
 
-        start_response(f"{status.value:d}\x20{status.phrase!s}", headers, exc_info)
+        start_response(f"{status.value:d}\u0020{status.phrase!s}", headers, exc_info)
         yield response_body
 
-    @classmethod
     @abstractmethod
-    def handle_request(cls, obj: _AnyRequest, /) -> _AnyResponse:
+    def handle_request(self, obj: _AnyRequest, /) -> _AnyResponse:
         raise NotImplementedError
 
-    @classmethod
     @abstractmethod
-    def process_request(cls, request_body: bytes, /) -> bytes:
+    def process_request(self, request_body: bytes, /) -> bytes:
         raise NotImplementedError
 
 
@@ -190,46 +216,51 @@ class WSGIHandler(BaseWSGIHandler):
     serializer: ClassVar[JSONSerializer] = JSONSerializer()
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}()>"
+        return f"<{__package__}.{self.__class__.__qualname__}()>"
 
-    @classmethod
-    def handle_request(cls, obj: _AnyRequest, /) -> _AnyResponse:
+    @singledispatchmethod
+    def handle_request(self, obj: _AnyRequest, /) -> _AnyResponse:
         """
-        Base method for handling deserialized requests.
+        Single-dispatch method for handling deserialized requests.
 
-        :param obj: One of the following objects types: :class:`jsonrpc.Request`, :class:`jsonrpc.Error`
-            or :class:`jsonrpc.BatchRequest`. If the :class:`jsonrpc.BatchRequest` object type was supplied,
+        :param obj: One of the following objects types: :class:`jsonrpc.Request`, :class:`jsonrpc.BatchRequest`
+            or :class:`jsonrpc.Error`. If the :class:`jsonrpc.BatchRequest` object type was supplied,
             its will be invoked itself recursively for each one item containing in the batch request.
+        :raises ValueError: Due the invocation with unsupported request type.
         :returns: Either :class:`jsonrpc.Response` or :class:`jsonrpc.BatchResponse`.
             If the :class:`jsonrpc.Request` object was received and it's the notification returns :py:data:`None`.
         """
-        if isinstance(obj, BatchRequest):
-            # We need to go deeper, 'cause received a batch request object.
-            # Then invoke itself recursively.
-            filterer: Callable[[_AnyResponse], bool] = lambda response: isinstance(response, Response)
-            return BatchResponse(filter(filterer, map(cls.handle_request, obj)))
+        raise ValueError(f"Unsupported type {type(obj).__name__!r}")
 
-        if isinstance(obj, Error):
-            # Returns the response as is with the error attribute.
-            return Response(error=obj, response_id=None)
+    @handle_request.register
+    def _(self, obj: Request, /) -> Response | None:
+        # Save the callback for future use:
+        dispatch: Final[partial] = partial(self.dispatcher.dispatch, obj.method)
+        # Redirect the method invocation to the separate thread,
+        # if the method is notification:
+        if obj.is_notification:
+            thread: Final[Thread] = Thread(target=dispatch, args=obj.args, kwargs=obj.kwargs)
+            return thread.start()
+        # Elsewise, execute the method as claimed and returns the error if an exception is raised:
+        try:
+            result: Final[Any] = dispatch(*obj.args, **obj.kwargs)
+            return Response(body=result, response_id=obj.request_id)
+        except Error as error:
+            return Response(error=error, response_id=obj.request_id)
 
-        if isinstance(obj, Request):
-            # Save the callback for future use:
-            dispatch: Final[partial] = partial(cls.dispatcher.dispatch, obj.method)
-            # Redirect the method invocation to the separate thread,
-            # if the method is notification:
-            if obj.is_notification:
-                thread: Final[Thread] = Thread(target=dispatch, args=obj.args, kwargs=obj.kwargs)
-                return thread.start()
-            # Elsewise, execute the method as claimed and returns the error if an exception is raised:
-            try:
-                result: Final[Any] = dispatch(*obj.args, **obj.kwargs)
-                return Response(body=result, response_id=obj.request_id)
-            except Error as error:
-                return Response(error=error, response_id=obj.request_id)
+    @handle_request.register
+    def _(self, obj: BatchRequest, /) -> BatchResponse:
+        # We need to go deeper, 'cause received a batch request object.
+        # Then invoke itself recursively.
+        filterer: Callable[[_AnyResponse], bool] = lambda response: isinstance(response, Response)
+        return BatchResponse(filter(filterer, map(self.handle_request, obj)))
 
-    @classmethod
-    def process_request(cls, request_body: bytes, /) -> bytes:
+    @handle_request.register
+    def _(self, obj: Error, /) -> Response:
+        # Returns the response as is with the error attribute.
+        return Response(error=obj, response_id=None)
+
+    def process_request(self, request_body: bytes, /) -> bytes:
         """
         Base method for consuming a raw requests from ``WSGI`` server and producing the serialized responses.
 
@@ -237,19 +268,19 @@ class WSGIHandler(BaseWSGIHandler):
         :returns: The :py:class:`bytes` object representing a serialized response body for next sending to ``WSGI`` server.
         """
         try:
-            obj: Any = cls.serializer.deserialize(request_body)
+            obj: Any = self.serializer.deserialize(request_body)
         except Error as error:
             deserialization_error: Response = Response(error=error, response_id=None)
-            return cls.serializer.serialize(deserialization_error.json)
+            return self.serializer.serialize(deserialization_error.json)
 
         is_batch_request: Final[bool] = isinstance(obj, MutableSequence) and len(obj) >= 1
         request: Final[_AnyRequest] = (BatchRequest if is_batch_request else Request).from_json(obj)
 
-        if not (response := cls.handle_request(request)):
+        if not (response := self.handle_request(request)):
             return b""
 
         try:
-            return cls.serializer.serialize(response.json)
+            return self.serializer.serialize(response.json)
         except Error as error:
             serialization_error: Response = Response(error=error, response_id=None)
-            return cls.serializer.serialize(serialization_error.json)
+            return self.serializer.serialize(serialization_error.json)
